# OryzenLabs SDK
OryzenAI API'sini kullanmak için resmi Python kütüphanesi.

Ben Can OryzenLabs in ve OryzenAI in kurucusu Bu kütüphaneyi bizler için yaptım örnek kod aşşağıda ama ondan önce bişe söylemeliyim api key almak için bunları yap:

1. https://rufina-unpermitting-lucidly.ngrok-free.dev/ adresine git ve hesap aç
2. api key oluştur butonuna bas ve keyi al
3. bu kodu kullanabilirsin:

from oryzenlabs import OryzenAI

client = OryzenAI()

client.getapi("osk_key", "ossec_secret")

cevap = client.send.response(send="Selam Oryzen!")
print(cevap)

bu kod ile her işi yaparsın daammı hadi iyi kullanımlar

## Kurulum
```bash
pip install oryzenlabs
```
